import boto
import subprocess

from linaro_chromiumos.utils import check_boto_version, remote_run
from unittest import TestCase

class TestCheckBotoVersion(TestCase):
    def mock_boto_version(self, mock_version):
        self.addCleanup(setattr, boto, 'Version', boto.Version)
        boto.Version = mock_version

    def test_check_boto_version(self):
        self.mock_boto_version('2.0b4')
        self.assertEqual(None, check_boto_version())

    def test_check_boto_version_too_old(self):
        self.mock_boto_version('1.8')
        self.assertRaises(ValueError, check_boto_version)

class TestRemoteRun(TestCase):
    def mock_Popen(self_test_remote_run, returncode):
        self_test_remote_run.saved_args = []

        class MockPopen:
            def __init__(self_mock_Popen, args):
                self_test_remote_run.saved_args.append(args)

            def wait(self):
                return returncode

        self_test_remote_run.addCleanup(
            setattr, subprocess, 'Popen', subprocess.Popen)
        subprocess.Popen = MockPopen

    def test_remote_run(self):
        self.mock_Popen(0)
        remote_run('machine', ['command', 'arg'])
        expected = [['ssh', 'machine', '--', 'command', 'arg']]
        self.assertEqual(expected, self.saved_args)

    def test_remote_run_failed_command(self):
        self.mock_Popen(1)
        self.assertRaises(ValueError, remote_run, 'machine', ['command'])

