"""Misc utilities.

Various small functions not big enough to justify their own files at the
moment.
"""

import boto
import subprocess

from distutils.version import LooseVersion

def check_boto_version():
    """Check whether we have a sufficiently recent boto."""
    actual = boto.Version
    required = '1.9b'
    if LooseVersion(actual) < LooseVersion(required):
        raise ValueError(
            "boto version %s is older than required version %s" % (
                actual, required))
    return

def remote_run(machine, args):
    """Run a command on a remote machine over SSH.

    :param machine: name of remote host"""
    ssh_args = ["ssh", machine, "--"] + args
    returncode = subprocess.Popen(ssh_args).wait()
    if returncode != 0:
        raise ValueError(
            "Command %s returned with non-zero exit code" % ssh_args)
    return

